@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/calma/CalmaRdcl.c,v 1.2 2008/06/01 18:37:37 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/calma/CalmaRdcl.c,v 1.3 2010/03/08 13:33:33 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -97,7 +97,7 @@ calmaSetPosition(sname)
     char *strname = NULL;
     int strRecSize = 0;
 
-    originalPos = ftell(calmaInputFile);
+    originalPos = ftello(calmaInputFile);
 
     while (feof(calmaInputFile) == 0)
     {
@@ -287,7 +287,7 @@ calmaParseStructure(filename)
     TxPrintf("Reading \"%s\".\n", strname);
 
     if (CalmaReadOnly)
-	filepos = ftell(calmaInputFile);
+	filepos = ftello(calmaInputFile);
 
     /* Set up the cell definition */
     he = HashFind(&calmaDefInitHash, strname);
@@ -366,7 +366,7 @@ calmaParseStructure(filename)
 	DBPropPut(cifReadCellDef, "GDS_START", (ClientData)fpcopy);
 
 	fpcopy = (char *)mallocMagic(20);
-	filepos = ftell(calmaInputFile);
+	filepos = ftello(calmaInputFile);
 	sprintf(fpcopy, "%d", filepos);
 	DBPropPut(cifReadCellDef, "GDS_END", (ClientData)fpcopy);
 
