@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdpoly.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdpoly.c,v 1.2 2010/05/21 20:30:03 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -30,7 +30,6 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "cif/CIFread.h"
 #include "utils/malloc.h"
 
-#define MAXPG 10000 	/* maximum # of points in polygon */
 #define HEDGE 0		/* Horizontal edge */
 #define REDGE 1		/* Rising edge */
 #define FEDGE -1	/* Falling edge */
@@ -239,10 +238,10 @@ CIFPolyToRects(path)
 {
 
 #endif
-    int npts = 0, n, dir[MAXPG], curr, wrapno;
+    int npts = 0, n, *dir, curr, wrapno;
     int xbot, xtop, ybot, ytop;
-    Point *pts[MAXPG];
-    CIFPath *p, *edges[MAXPG], *tail = 0;
+    Point **pts;
+    CIFPath *p, **edges, *tail = 0;
     LinkedRect *rex = 0, *new;
 
     /* Close path list. */
@@ -264,21 +263,22 @@ CIFPolyToRects(path)
     CIFMakeManhattanPath(path);
 #endif
 
-    for (p = path; p->cifp_next; p = p->cifp_next, npts += 1)
+    for (p = path; p->cifp_next; p = p->cifp_next, npts++);
+    pts = (Point **)mallocMagic(npts * sizeof(Point *));
+    dir = (int *)mallocMagic(npts * sizeof(int));
+    edges = (CIFPath **)mallocMagic(npts * sizeof(CIFPath *));
+    npts = 0;
+
+    for (p = path; p->cifp_next; p = p->cifp_next, npts++)
     {
-	if (npts >= MAXPG)
-	{
-	    CIFReadError("polygon with more than %d points.\n", MAXPG );
-	    goto done;
-	}
 	pts[npts] = &(p->cifp_point);
 	edges[npts] = p;
     }
 
     if (npts < 4)
     {
-	    CIFReadError("polygon with fewer than 4 points.\n" );
-	    goto done;
+	CIFReadError("polygon with fewer than 4 points.\n" );
+	goto done;
     }
 
     /* Sort points by low y, edges by low x */
@@ -290,8 +290,8 @@ CIFPolyToRects(path)
 
     if (!cifOrient (edges, npts, dir))
     {
-	    CIFReadError("non-manhattan polygon.\n" );
-	    goto done;
+	CIFReadError("non-manhattan polygon.\n" );
+	goto done;
     }
 
     /* Scan the polygon from bottom to top.  At each step, process
@@ -342,5 +342,8 @@ CIFPolyToRects(path)
      */
 
 done:
+    freeMagic((char *)edges);
+    freeMagic((char *)dir);
+    freeMagic((char *)pts);
     return (rex);
 }
