@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdutils.c,v 1.2 2008/06/01 18:37:38 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/cif/CIFrdutils.c,v 1.3 2010/05/21 22:15:11 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -851,32 +851,34 @@ path_intersect(pathHead, start, respt)
 	    diagonal = TRUE;
 	}
 
-	/* Is the point inside the triangle (path must 			*/
-	/* be Manhattan in this case, unless the path crosses itself,	*/
-	/* which would be extremely bad CIF to begin with).		*/
+	/* Is the point inside the triangle, and the path is Manhattan?	*/
 	/* (Note that *both* tests can be true, in which case the one	*/
 	/* with the smaller absolute distance takes precedence.)	*/
 
 	if (test_insideness(start, &path->cifp_point)) {
 	    int tmpdist = abs(newdist);		/* save this value */	
-	    if (start->cifp_x == start->cifp_next->cifp_x)
+	    if (path->cifp_x == path->cifp_next->cifp_x ||
+			path->cifp_y == path->cifp_next->cifp_y)
 	    {
-		newdist = path->cifp_y - start->cifp_y;
-		if (abs(newdist) < tmpdist)
+		if (start->cifp_x == start->cifp_next->cifp_x)
 		{
-		    tmppt.p_x = start->cifp_x;
-		    tmppt.p_y = path->cifp_y;
-		    diagonal = FALSE;
+		    newdist = path->cifp_y - start->cifp_y;
+		    if (abs(newdist) < tmpdist)
+		    {
+			tmppt.p_x = start->cifp_x;
+			tmppt.p_y = path->cifp_y;
+			diagonal = FALSE;
+		    }
 		}
-	    }
-	    else
-	    {
-		newdist = path->cifp_x - start->cifp_x;
-		if (abs(newdist) < tmpdist)
+		else
 		{
-		    tmppt.p_y = start->cifp_y;
-		    tmppt.p_x = path->cifp_x;
-		    diagonal = FALSE;
+		    newdist = path->cifp_x - start->cifp_x;
+		    if (abs(newdist) < tmpdist)
+		    {
+			tmppt.p_y = start->cifp_y;
+			tmppt.p_x = path->cifp_x;
+			diagonal = FALSE;
+		    }
 		}
 	    }
 	}
