@@ -17,7 +17,7 @@
  *     *********************************************************************
  *
  *
- * rcsid "$Header: /usr/cvsroot/magic-8.0/cif/cif.h,v 1.2 2008/12/03 14:12:08 tim Exp $
+ * rcsid "$Header: /usr/cvsroot/magic-8.0/cif/cif.h,v 1.3 2010/05/04 20:14:13 tim Exp $
  */
 
 #ifndef _CIF_H
@@ -34,7 +34,6 @@
 
 extern int  CIFWarningLevel;
 extern int  CIFRescaleLimit;
-extern bool CIFSubcellPolygons;
 extern bool CIFRescaleAllow;
 extern bool CIFDoAreaLabels;
 extern bool CIFDoCellIdLabels;
@@ -42,6 +41,10 @@ extern char *CIFPathPrefix;
 extern char *CIFErrorFilename;
 extern bool CIFArrayWriteDisable;
 extern bool CIFHierWriteDisable;
+#ifdef NONMANHATTAN
+extern bool CIFSubcellPolygons;
+extern bool CIFUnfracture;
+#endif
 
 /* Procedures that parse the cif sections of a technology file. */
 
