@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdRS.c,v 1.8 2008/12/11 14:11:45 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdRS.c,v 1.10 2010/05/04 18:40:55 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -2149,7 +2149,7 @@ CmdSplit(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    Rect editRect;
+    Rect editRect, expRect;
     TileTypeBitMask mask1, mask2, *cmask;
     TileType t, dir, side, diag;
     int pNum, direction;
@@ -2208,6 +2208,9 @@ CmdSplit(w, cmd)
 			ui.pu_pNum = pNum;
 			DBNMPaintPlane(EditCellUse->cu_def->cd_planes[pNum],
 				diag, &editRect, DBStdPaintTbl(t, pNum), &ui);
+			GEO_EXPAND(&editRect, 1, &expRect);
+			DBMergeNMTiles(EditCellUse->cu_def->cd_planes[pNum],
+				&expRect);
 		    }
 	    }
 	}
@@ -2241,7 +2244,7 @@ CmdSplitErase(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    Rect editRect;
+    Rect editRect, expRect;
     TileTypeBitMask mask;
     TileType t, dir, side, diag;
     int pNum, direction;
@@ -2294,6 +2297,9 @@ CmdSplitErase(w, cmd)
 		    ui.pu_pNum = pNum;
 		    DBNMPaintPlane(EditCellUse->cu_def->cd_planes[pNum],
 				diag, &editRect, DBStdEraseTbl(t, pNum), &ui);
+		    GEO_EXPAND(&editRect, 1, &expRect);
+		    DBMergeNMTiles(EditCellUse->cu_def->cd_planes[pNum],
+				&expRect);
 		}
 	}
     }
