@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/commands/CmdSubrs.c,v 1.4 2007/03/18 15:20:40 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdSubrs.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -287,7 +287,7 @@ cmdFlushCell(def)
     CellUse *parentUse;
 
     /* Disallow flushing a cell that contains the edit cell as a child */
-    if (EditCellUse->cu_parent == def)
+    if (EditCellUse && (EditCellUse->cu_parent == def))
     {
 	TxError("Cannot flush cell whose subcell is being edited.\n");
 	TxError("%s not flushed\n", def->cd_name);
@@ -411,85 +411,87 @@ CmdParseLayers(s, mask)
 	    continue;
 
 	TTMaskZero(&newmask);
-	which = LookupStruct(name, (LookupTable *) special, sizeof special[0]);
-	if (which >= 0)
+
+	type = DBTechNameTypes(name, &newmask);
+	if (type == -2)
 	{
-	    switch (special[which].layer_value)
+	    which = LookupStruct(name, (LookupTable *) special, sizeof special[0]);
+	    if (which >= 0)
 	    {
-		case LN_LABELS:
-		    TTMaskSetType(&newmask, L_LABEL);
-		    break;
-		case LN_CELL:
-		    TTMaskSetType(&newmask, L_CELL);
-		    break;
-		/*
-		 * All layers currently beneath the point tool.
-		 * Currently, neither labels nor cells are ever included
-		 * in this.
-		 */
-		case LN_DOLLAR:
-		    window = CmdGetRootPoint((Point *) NULL, &rootRect);
-		    if ((window == (MagWindow *) NULL)
-			    || (window->w_client != DBWclientID))
-			return (FALSE);
-		    crec = (DBWclientRec *) window->w_clientData;
-		    DBSeeTypesAll(((CellUse *)window->w_surfaceID), 
-			&rootRect, crec->dbw_bitmask, &newmask);
-		    TTMaskAndMask(&newmask, &crec->dbw_visibleLayers);
-		    tempmask = DBAllButSpaceAndDRCBits;
-		    TTMaskSetType(&tempmask, TT_SPACE);
-		    TTMaskAndMask(&newmask, &tempmask);
-		    break;
-		/*
-		 * Everything but labels and subcells
-		 */
-		case LN_ALL:
-		    newmask = DBAllButSpaceAndDRCBits;
-		    TTMaskClearType(&newmask, L_LABEL);
-		    TTMaskClearType(&newmask, L_CELL);
-		    break;
-		/*
-		 * All DRC error layers.
-		 */
-		case LN_ERRORS:
-		    TTMaskSetType(&newmask, TT_ERROR_P);
-		    TTMaskSetType(&newmask, TT_ERROR_S);
-		    TTMaskSetType(&newmask, TT_ERROR_PS);
-		    break;
-		/*
-		 * Add in all layers connected to layers already parsed
-		 */
-		case LN_CONNECT:
-		    for (type = TT_TECHDEPBASE; type < DBNumTypes; type++)
-			if (TTMaskHasType(mask, type))
-			{
-			    TileType ttype;
-			    for (ttype = TT_TECHDEPBASE; ttype < DBNumTypes; ttype++)
-				if (DBConnectsTo(type, ttype))
-				    TTMaskSetType(&newmask, ttype);
-			}
-		    break;
+		switch (special[which].layer_value)
+		{
+		    case LN_LABELS:
+			TTMaskSetType(&newmask, L_LABEL);
+			break;
+		    case LN_CELL:
+			TTMaskSetType(&newmask, L_CELL);
+			break;
+		    /*
+		     * All layers currently beneath the point tool.
+		     * Currently, neither labels nor cells are ever included
+		     * in this.
+		     */
+    		    case LN_DOLLAR:
+			window = CmdGetRootPoint((Point *) NULL, &rootRect);
+			if ((window == (MagWindow *) NULL)
+			    	|| (window->w_client != DBWclientID))
+			    return (FALSE);
+			crec = (DBWclientRec *) window->w_clientData;
+			DBSeeTypesAll(((CellUse *)window->w_surfaceID), 
+				&rootRect, crec->dbw_bitmask, &newmask);
+			TTMaskAndMask(&newmask, &crec->dbw_visibleLayers);
+			tempmask = DBAllButSpaceAndDRCBits;
+			TTMaskSetType(&tempmask, TT_SPACE);
+			TTMaskAndMask(&newmask, &tempmask);
+			break;
+		    /*
+		     * Everything but labels and subcells
+		     */
+		    case LN_ALL:
+			newmask = DBAllButSpaceAndDRCBits;
+			TTMaskClearType(&newmask, L_LABEL);
+			TTMaskClearType(&newmask, L_CELL);
+			break;
+		    /*
+		     * All DRC error layers.
+		     */
+		    case LN_ERRORS:
+			TTMaskSetType(&newmask, TT_ERROR_P);
+			TTMaskSetType(&newmask, TT_ERROR_S);
+			TTMaskSetType(&newmask, TT_ERROR_PS);
+			break;
+		    /*
+		     * Add in all layers connected to layers already parsed
+		     */
+		    case LN_CONNECT:
+			for (type = TT_TECHDEPBASE; type < DBNumTypes; type++)
+			    if (TTMaskHasType(mask, type))
+			    {
+				TileType ttype;
+				for (ttype = TT_TECHDEPBASE; ttype < DBNumTypes; ttype++)
+				    if (DBConnectsTo(type, ttype))
+					TTMaskSetType(&newmask, ttype);
+			    }
+			break;
+		}
+	    }
+	    else
+	    {
+		TxError("Unrecognized layer: %s\n", name);
+printTypes:
+		DBTechPrintTypes(&DBAllButSpaceAndDRCBits, FALSE);
+		for (i = 0; ; i++)
+		{
+		    if (special[i].layer_name == NULL) break;
+		    TxError("    %s\n", special[i].layer_name);
+		}
+		return (FALSE);
 	    }
 	}
-	else
+	else if (type == -1)
 	{
-	    type = DBTechNameTypes(name, &newmask);
-	    switch (type)
-	    {
-		case -2:
-		    TxError("Unrecognized layer: %s\n", name);
-		    printTypes:
-		    DBTechPrintTypes(FALSE);
-		    for (i = 0; ; i++)
-		    {
-			if (special[i].layer_name == NULL) break;
-			TxError("    %s\n", special[i].layer_name);
-		    }
-		    return (FALSE);
-		case -1:
-		    TxError("Ambiguous layer: %s\n", name);
-		    goto printTypes;
-	    }
+	    TxError("Ambiguous layer: %s\n", name);
+	    goto printTypes;
 	}
 
 	if (adding)
