@@ -17,7 +17,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBcell.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBcell.c,v 1.2 2008/12/11 04:20:04 tim Exp $";
 #endif	/* not lint */
 
 #include <sys/types.h>
@@ -141,7 +141,8 @@ DBPlaceCell (celluse, targetcell)
     ASSERT(celluse != (CellUse *) NULL, "DBPlaceCell");
     celluse->cu_parent = targetcell;
     plane = targetcell->cd_planes[PL_CELL];                   /* assign plane */
-    rect = celluse->cu_bbox;
+    /* rect = celluse->cu_bbox; */
+    rect = celluse->cu_extended;
     arg.rect = &rect;
     arg.celluse = celluse;
     arg.plane = plane;
