@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBcellcopy.c,v 1.10 2009/05/03 15:01:04 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBcellcopy.c,v 1.11 2010/05/11 19:28:53 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -106,6 +106,7 @@ DBPaintPlaneWrapper(def, pNum, type, area, undo)
 {
 #ifdef NONMANHATTAN
     TileType loctype = type & TT_LEFTMASK;
+    Rect expand;
 #else
     TileType loctype = type;
 #endif
@@ -114,6 +115,8 @@ DBPaintPlaneWrapper(def, pNum, type, area, undo)
 #ifdef NONMANHATTAN
     DBNMPaintPlane(def->cd_planes[pNum], type, area,
 		dbCurPaintTbl[pNum][loctype], undo);
+    GEO_EXPAND(area, 1, &expand);
+    DBMergeNMTiles(def->cd_planes[pNum], &expand);
 #else
     DBPaintPlane(def->cd_planes[pNum], area,
 		dbCurPaintTbl[pNum][loctype], undo);
