@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBundo.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/database/DBundo.c,v 1.2 2009/05/02 01:18:36 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -567,6 +567,7 @@ dbUndoLabelBack(up)
 	CellDef		*cue_def;
 	CellDef		*cue_parent;
 	Rect		 cue_bbox;
+	Rect		 cue_extended;
 	unsigned char	 cue_flags;
 	char		 cue_id[4];
     } cellUE;
@@ -623,6 +624,7 @@ DBUndoCellUse(use, action)
     up->cue_parent = use->cu_parent;
     up->cue_expandMask = use->cu_expandMask;
     up->cue_bbox = use->cu_bbox;
+    up->cue_extended = use->cu_extended;
     up->cue_flags = use->cu_flags;
     strcpy(up->cue_id, use->cu_id);
 }
@@ -658,6 +660,7 @@ dbUndoCellForw(up)
 	    use->cu_array = up->cue_array;
 	    use->cu_expandMask = up->cue_expandMask;
 	    use->cu_bbox = up->cue_bbox;
+	    use->cu_extended = up->cue_extended;
 	    use->cu_flags = up->cue_flags; 
 	    use->cu_id = StrDup((char **) NULL, up->cue_id);
 	    (void) DBLinkCell(use, up->cue_parent);
@@ -726,6 +729,7 @@ dbUndoCellBack(up)
 	    use->cu_array = up->cue_array;
 	    use->cu_expandMask = up->cue_expandMask;
 	    use->cu_bbox = up->cue_bbox;
+	    use->cu_extended = up->cue_extended;
 	    use->cu_flags = up->cue_flags; 
 	    use->cu_id = StrDup((char **) NULL, up->cue_id);
 	    SigDisableInterrupts ();
