@@ -24,7 +24,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCcif.c,v 1.2 2008/02/12 03:15:21 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCcif.c,v 1.3 2010/05/13 21:28:52 tim Exp $";
 #endif	/* not lint */
 
 #include <stdio.h>
@@ -339,6 +339,38 @@ drcCifSpacing(argc, argv)
     return ((centidistance+scalefactor-1)/scalefactor);
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ * Scale CIF/DRC rules to match grid scaling.  Scale by factor (n / d)
+ * ----------------------------------------------------------------------------
+ */
+
+void
+drcCifScale(int n, int d)
+{
+    DRCCookie *dp;
+    int i, j;
+
+    if (DRCCurStyle != NULL)
+    {
+	for (i = 0; i != MAXCIFLAYERS; i++)
+	    for (j = 0; j < 2; j++)
+		for (dp = drcCifRules[i][j]; dp != NULL; dp = dp->drcc_next)
+		{
+		    if (dp->drcc_dist != 0)
+		    {
+			dp->drcc_dist *= n;
+			dp->drcc_dist /= d;
+		    }
+		    if (dp->drcc_cdist != 0)
+		    {
+			dp->drcc_cdist *= n;
+			dp->drcc_cdist /= d;
+		    }
+		}
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  * ----------------------------------------------------------------------------
