@@ -19,7 +19,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCmain.c,v 1.2 2009/09/11 15:47:09 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCmain.c,v 1.3 2010/03/08 13:33:33 tim Exp $";
 #endif	/* not lint */
 
 #include <sys/types.h>
@@ -37,9 +37,6 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "drc/drc.h"
 #include "utils/undo.h"
 
-extern void TxPrintf(char *, ...);
-extern void TxError(char *, ...);
-
 /* The global variables defined below are parameters between
  * the DRC error routines (drcPaintError and drcPrintError)
  * and the higher-level routines that start up DRC error checks.
