@@ -19,7 +19,7 @@
  */
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCsubcell.c,v 1.3 2008/06/01 18:37:40 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCsubcell.c,v 1.4 2009/05/01 18:59:44 tim Exp $";
 #endif	/* not lint */
 
 #include <stdio.h>
@@ -583,12 +583,12 @@ DRCInteractionCheck(def, area, func, cdarg)
 	    DBCellClearDef(DRCdef);
 
 	    savedPaintTable = DBNewPaintTable(DRCCurStyle->DRCPaintTable);
-	    /* savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce); */
+	    savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMark);
 
 	    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceBits, 0, DRCuse);
 
 	    (void) DBNewPaintTable(savedPaintTable);
-	    /* (void) DBNewPaintPlane(savedPaintPlane); */
+	    (void) DBNewPaintPlane(savedPaintPlane);
 
 	    /* Run the basic checker over the interaction area. */
 
@@ -650,12 +650,12 @@ DRCFlatCheck(use, area)
 	    DBCellClearDef(DRCdef);
 
 	    savedPaintTable = DBNewPaintTable(DRCCurStyle->DRCPaintTable);
-	    /* savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMergeOnce); */
+	    savedPaintPlane = DBNewPaintPlane(DBPaintPlaneMark);
 
 	    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceBits, 0, DRCuse);
 
 	    (void) DBNewPaintTable(savedPaintTable);
-	    /* (void) DBNewPaintPlane(savedPaintPlane); */
+	    (void) DBNewPaintPlane(savedPaintPlane);
 
 	    (void) DRCBasicCheck(DRCdef, &scx.scx_area, &chunk,
 		drcIncCount, (ClientData) &drcFlatCount);
