@@ -13,7 +13,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/ext2spice/ext2spice.c,v 1.3 2008/12/03 14:12:09 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/ext2spice/ext2spice.c,v 1.5 2009/09/10 20:32:52 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1601,9 +1601,11 @@ spcdevVisit(dev, hierName, trans)
     switch(dev->dev_class)
     {
 	case DEV_MOSFET:
+	case DEV_ASYMMETRIC:
 	case DEV_FET:
 	    if (source == drain)
 		fprintf(esSpiceF, "** SOURCE/DRAIN TIED\n");
+	    break;
 
 	default:
 	    if (gate == source)
@@ -1615,6 +1617,7 @@ spcdevVisit(dev, hierName, trans)
     switch(dev->dev_class)
     {
 	case DEV_MOSFET:
+	case DEV_ASYMMETRIC:
 	case DEV_FET:
 	    devchar = 'M';
 	    break;
@@ -1906,6 +1909,7 @@ spcdevVisit(dev, hierName, trans)
 
 	case DEV_FET:
 	case DEV_MOSFET:
+	case DEV_ASYMMETRIC:
 
 	    /* MOSFET is "Mnnn drain gate source [L=x W=x [attributes]]" */
 
@@ -2465,7 +2469,7 @@ EFHNSprintf(str, hierName)
 {
     bool trimGlob, trimLocal;
     char *s, *cp, c;
-    char *efHNSprintfPrefix();
+    char *efHNSprintfPrefix(HierName *, char *);
 
     s = str;
     if (hierName->hn_parent) str = efHNSprintfPrefix(hierName->hn_parent, str);
@@ -2708,6 +2712,16 @@ parallelDevs(f1, f2)
 	    }
 	    break;
 
+	case DEV_ASYMMETRIC:
+
+	    if (f1->b != f2->b) return NOT_PARALLEL;
+	    if ((f1->g == f2->g) && (f1->d == f2->d) && (f1->s == f2->s)
+			&& (f1->l == f2->l) && (esMergeDevsA || (f1->w == f2->w)))
+	    {
+		    return PARALLEL;
+	    }
+	    break;
+
 	/* Capacitors match if top ("gate") and bottom ("source") are	*/
 	/* the same.  Do not attempt to swap top and bottom, as we do	*/
 	/* not know when it is safe to do so.				*/
@@ -2911,6 +2925,7 @@ mergeThem:
 	    switch(dev->dev_class)
 	    {
 		case DEV_MOSFET:
+		case DEV_ASYMMETRIC:
 		case DEV_FET:
 		    m = esFMult[cfp->esFMIndex] + ((float)fp->w / (float)cfp->w);
 		    break;
