@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFname.c,v 1.4 2001/07/06 17:58:39 rajit Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extflat/EFname.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -69,7 +69,9 @@ extern void efHNRecord();
  * i.e, it ends in a '!'.
  * 
  * The Tcl version of magic further refines this to include names
- * which are defined in the global Tcl variable space.
+ * which are defined in the global Tcl variable space.  (7.3.94):
+ * also check if the array variable "globals" contains the name as
+ * a key entry.
  *
  * Results:
  *	TRUE if the name is a global.
@@ -86,6 +88,10 @@ EFHNIsGlob(hierName)
 {
 #ifdef MAGIC_WRAPPER
     char *retstr;
+    retstr = (char *)Tcl_GetVar2(magicinterp, "globals", hierName->hn_name,
+		TCL_GLOBAL_ONLY);
+    if (retstr != NULL) return TRUE;
+
     retstr = (char *)Tcl_GetVar(magicinterp, hierName->hn_name, TCL_GLOBAL_ONLY);
     if (retstr != NULL) return TRUE;
 #endif
@@ -695,7 +701,7 @@ int
 efHNUseHash(hierName)
     HierName *hierName;
 {
-    return hierName->hn_hash + (int) hierName->hn_parent;
+    return hierName->hn_hash + (spointertype) hierName->hn_parent;
 }
 
 /*
