@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extflat/EFread.c,v 1.3 2009/01/19 15:43:03 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extflat/EFread.c,v 1.4 2009/01/30 03:51:02 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -42,8 +42,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 
 #ifndef MAGIC_WRAPPER
 /* This must match the definition for extDevTable in extract/ExtBasic.c */
-char *extDevTable[] = {"fet", "mosfet", "bjt", "devres", "devcap",
-		"diode", "subckt", "rsubckt", NULL};
+char *extDevTable[] = {"fet", "mosfet", "asymmetric", "bjt", "devres",
+		"devcap", "diode", "subckt", "rsubckt", NULL};
 #endif
 
 /*
@@ -284,6 +284,7 @@ readfile:
 		switch (n)
 		{
 		    case DEV_MOSFET:
+		    case DEV_ASYMMETRIC:
 		    case DEV_BJT:
 			ac = 10;
 			break;
