@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/extract/ExtCouple.c,v 1.1.1.1 2006/04/10 22:03:14 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtCouple.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -282,6 +282,9 @@ extBasicOverlap(tile, ecs)
 #endif
     thisType = TiGetTypeExact(tile);
 
+    if (DBIsContact(thisType))
+	thisType = DBPlaneToResidue(thisType, thisPlane);
+
     pMask = ExtCurStyle->exts_overlapOtherPlanes[thisType];
     tMask = &ExtCurStyle->exts_overlapOtherTypes[thisType];
 
@@ -390,7 +393,7 @@ extAddOverlap(tbelow, ecpls)
 	ta = DBPlaneToResidue(ta, ecpls->plane_of_tile);
 
     if (DBIsContact(tb))
-	tb = DBPlaneToResidue(ta, ecpls->plane_checked);
+	tb = DBPlaneToResidue(tb, ecpls->plane_checked);
 
     /*
      * Find whether rabove and rbelow are shielded by intervening material.
@@ -558,7 +561,7 @@ extBasicCouple(tile, ecs)
     extCapStruct *ecs;
 {
     (void) extEnumTilePerim(tile, ExtCurStyle->exts_sideEdges[TiGetType(tile)],
-			extAddCouple, (ClientData) ecs);
+			ecs->plane, extAddCouple, (ClientData) ecs);
     return (0);
 }
 
@@ -608,11 +611,11 @@ extAddCouple(bp, ecs)
     CellDef *def = ecs->def;
     extSidewallStruct esws;
 
-    /* Revert any contacts to their residues */
+    /* Revert any edge contacts to their residues */
     if (DBIsContact(tin))
 	tin = DBPlaneToResidue(tin, ecs->plane);
     if (DBIsContact(tout))
-	tin = DBPlaneToResidue(tout, ecs->plane);
+	tout = DBPlaneToResidue(tout, ecs->plane);
 
     extCoupleList = ExtCurStyle->exts_sideCoupleCap[tin][tout];
     extOverlapList = ExtCurStyle->exts_sideOverlapCap[tin][tout];
@@ -754,10 +757,9 @@ extSideOverlap(tp, esws)
     cap = (CapValue) 0;
     for (e = extOverlapList; e; e = e->ec_next)
     {
-	/* For a rule that specifies an overlap of space, it applies only to
-	 * space on a particular plane.
-	 */
-	if (tb == TT_SPACE && bp->b_plane != e->ec_plane) continue;
+	/* Only apply rules for the plane in which they are declared */
+	if (!PlaneMaskHasPlane(e->ec_pmask, esws->plane_checked)) continue;
+
 	/* Does this rule "e" include the tile we found? */
 	if (TTMaskHasType(&e->ec_near, TiGetType(tp)))
 	{
