@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtHier.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/extract/ExtHier.c,v 1.2 2009/05/30 03:14:00 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -350,7 +350,10 @@ extHierAdjustments(ha, cumFlat, oneFlat, lookFlat)
      */
     for (np = oneFlat->et_nodes; np; np = np->nreg_next)
     {
-	NODETOTILE(np, lookFlat, tp);  /* tp = extHierLookTile(np, lookFlat); */
+	/* Ignore orphaned nodes (non-Manhattan shards outside the clip box) */
+	if (np->nreg_pnum == DBNumPlanes) continue;
+
+	tp = extNodeToTile(np, lookFlat);
 	if (tp	&& (name = (*ha->ha_nodename)(tp, np->nreg_pnum, lookFlat, ha, FALSE))
 		&& (he = HashLookOnly(&ha->ha_connHash, name))
 		&& (nn = (NodeName *) HashGetValue(he)))
