@@ -4,7 +4,7 @@
  * Defines things shared internally by the extract module of Magic,
  * but not generally needed outside the extract module.
  *
- * rcsid "$Header: /usr/cvsroot/magic-8.0/extract/extractInt.h,v 1.4 2008/12/11 17:16:41 tim Exp $"
+ * rcsid "$Header: /usr/cvsroot/magic-8.0/extract/extractInt.h,v 1.5 2009/05/30 03:14:00 tim Exp $"
  *
  *     ********************************************************************* 
  *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
@@ -968,26 +968,9 @@ extern Region *extResFirst();		extern int extResEach();
 extern Region *extNodeFirst();		extern int extNodeEach();
 extern Region *extHierLabFirst();	extern int extHierLabEach();
 
-/* -------- Search for matching tile/node in another ExtTree ---------- */
+extern Tile *extNodeToTile();
 
-/*
- * NODETOTILE(np, et, tp)
- *	NodeRegion *np;
- *	ExtTree *et;
- *	Tile *tp;
- *
- * Sets tp to be the tile containing the lower-leftmost point of the
- * NodeRegion *np, but in the tile planes of the ExtTree *et instead
- * of the tile planes originally containing *np.
- */
-#define	NODETOTILE(np, et, tp) \
-	if (1) { \
-	    Plane *myplane = (et)->et_use->cu_def->cd_planes[(np)->nreg_pnum]; \
-\
-	    (tp) = myplane->pl_hint; \
-	    GOTOPOINT(tp, &(np)->nreg_ll); \
-	    myplane->pl_hint = (tp); \
-	}
+/* -------- Search for matching node in another ExtTree ---------- */
 
 /*
  * NODETONODE(nold, et, nnew)
@@ -995,7 +978,7 @@ extern Region *extHierLabFirst();	extern int extHierLabEach();
  *	ExtTree *et;
  *	NodeRegion *nnew;
  *
- * Like NODETOTILE above, but leaves nnew pointing to the node associated
+ * Like extNodeToTile(), but leaves nnew pointing to the node associated
  * with the tile we find.
  */
 #define	NODETONODE(nold, et, nnew) \
@@ -1003,7 +986,7 @@ extern Region *extHierLabFirst();	extern int extHierLabEach();
 	    Tile *tp; \
  \
 	    (nnew) = (NodeRegion *) NULL; \
-	    NODETOTILE((nold), (et), tp); \
+	    tp = extNodeToTile((nold), (et)); \
 	    if (tp && extHasRegion(tp, extUnInit)) \
 		(nnew) = (NodeRegion *) extGetRegion(tp); \
 	}
