@@ -16,7 +16,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/gcr/gcrDebug.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/gcr/gcrDebug.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -181,7 +181,7 @@ gcrMakeChannel(ch, fp)
 	    TxError("Format error in pin-id in channel file\n");
 	    return (FALSE);
 	}
-	ch->gcr_bPins[i].gcr_pId = (GCRNet *) pid;
+	ch->gcr_bPins[i].gcr_pId = (GCRNet *)(spointertype) pid;
 	ch->gcr_bPins[i].gcr_x = i;
 	ch->gcr_bPins[i].gcr_y = 0;
 
@@ -222,7 +222,7 @@ gcrMakeChannel(ch, fp)
 	    TxError("Format error in router input file\n");
 	    return (FALSE);
 	}
-	ch->gcr_tPins[i].gcr_pId = (GCRNet *) pid;
+	ch->gcr_tPins[i].gcr_pId = (GCRNet *)(spointertype) pid;
 	ch->gcr_tPins[i].gcr_x = i;
 	ch->gcr_tPins[i].gcr_y = ch->gcr_width + 1;
     }
