@@ -19,7 +19,7 @@
 
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/graphics/grClip.c,v 1.2 2008/12/11 04:20:06 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/graphics/grClip.c,v 1.3 2010/05/11 19:28:53 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1220,7 +1220,7 @@ GrClipTriangle(r, c, clipped, dinfo, points, np)
         dlong width = (dlong)(r->r_xtop - r->r_xbot);
 	dlong height = (dlong)(r->r_ytop - r->r_ybot);
 
-	switch(dinfo)
+	switch(dinfo & (TT_DIAGONAL | TT_DIRECTION | TT_SIDE))
 	{
 	    case TT_DIAGONAL:	/* nw */
 		if (c->r_ytop < r->r_ytop)	/* clip top */
@@ -1394,7 +1394,7 @@ GrClipTriangle(r, c, clipped, dinfo, points, np)
 		    points[3].p_y = points[2].p_y - yround(dely);
 		    *np = 4;
 
-		    if (c->r_ybot > points[3].p_y)  /* clip BOTTOM, rectangle */
+		    if (c->r_ybot >= points[3].p_y)  /* clip BOTTOM, rectangle */
 		    {
 			points[3].p_y = c->r_ybot;
 			points[0].p_y = c->r_ybot;
