@@ -512,7 +512,7 @@ groglFontText(text, font, size, rotate, pos, clip, obscure)
 
 #endif /* VECTOR_FONTS */
 
-static GC grXcopyGC;
+static GC grXcopyGC = (GC)NULL;
 
 /*
  * ----------------------------------------------------------------------------
@@ -534,7 +534,7 @@ groglFreeBackingStore(MagWindow *window)
     if (pmap == (Pixmap)NULL) return;
     XFreePixmap(grXdpy, pmap);
     window->w_backingStore = (ClientData)NULL;
-    XFreeGC(grXdpy, grXcopyGC);
+    /* XFreeGC(grXdpy, grXcopyGC); */
     /* TxPrintf("groglFreeBackingStore called\n"); */
 }
 
@@ -573,8 +573,11 @@ groglCreateBackingStore(MagWindow *w)
 
     if (w->w_backingStore != (ClientData)NULL) groglFreeBackingStore(w);
 
-    gcValues.graphics_exposures = FALSE;
-    grXcopyGC = XCreateGC(grXdpy, wind, GCGraphicsExposures, &gcValues);
+    if (grXcopyGC == (GC)NULL)
+    {
+	gcValues.graphics_exposures = FALSE;
+	grXcopyGC = XCreateGC(grXdpy, wind, GCGraphicsExposures, &gcValues);
+    }
 
     pmap = XCreatePixmap(grXdpy, wind, width, height, oglCurrent.depth);
     w->w_backingStore = (ClientData)pmap;
