@@ -517,8 +517,15 @@ TOGLEventProc(clientData, xevent)
 
 keys_and_buttons:
 
-		keymod = (LockMask | ControlMask | ShiftMask | Mod1Mask)
+		keymod = (LockMask | ControlMask | ShiftMask)
 				& KeyPressedEvent->state;
+#ifdef macosx
+		if (KeyPressedEvent->state & (Mod1Mask | Mod2Mask |
+				Mod3Mask | Mod4Mask | Mod5Mask))
+		    keymod |= Mod1Mask;
+#else
+		keymod |= (Mod1Mask & KeyPressedEvent->state);
+#endif
 
 		if (nbytes == 0)	/* No ASCII equivalent */
 		{
@@ -589,9 +596,10 @@ keys_and_buttons:
 			        TxSetPoint(KeyPressedEvent->x,
 					grXtransY(mw, KeyPressedEvent->y),
 					mw->w_wid);
-				TxInputRedirect = TX_INPUT_NORMAL;
+				TxInputRedirect = TX_INPUT_PROCESSING;
 				Tcl_EvalEx(consoleinterp, "::tkcon::Eval .text",
 						19, 0);
+				TxInputRedirect = TX_INPUT_NORMAL;
 				TxSetPrompt('%');
 
 				Tcl_SaveResult(magicinterp, &state);
