@@ -329,7 +329,7 @@ GrX11BitBlt(r, p)
 	      p->p_x, grMagicToX(p->p_y));
 }
 
-static GC grXcopyGC;
+static GC grXcopyGC = (GC)NULL;
 
 /*
  * ----------------------------------------------------------------------------
@@ -351,7 +351,7 @@ grx11FreeBackingStore(MagWindow *window)
     if (pmap == (Pixmap)NULL) return;
     XFreePixmap(grXdpy, pmap);
     window->w_backingStore = (ClientData)NULL;
-    XFreeGC(grXdpy, grXcopyGC);
+    /* XFreeGC(grXdpy, grXcopyGC); */
     /* TxPrintf("grx11FreeBackingStore called\n"); */
 }
 
@@ -391,8 +391,11 @@ grx11CreateBackingStore(MagWindow *w)
 
     if (w->w_backingStore != (ClientData)NULL) grx11FreeBackingStore(w);
 
-    gcValues.graphics_exposures = FALSE;
-    grXcopyGC = XCreateGC(grXdpy, wind, GCGraphicsExposures, &gcValues);
+    if (grXcopyGC == (GC)NULL)
+    {
+	gcValues.graphics_exposures = FALSE;
+	grXcopyGC = XCreateGC(grXdpy, wind, GCGraphicsExposures, &gcValues);
+    }
 
     grDepth = grDisplay.depth;
     if(grClass == 3) grDepth = 8;  /* Needed since grDisplay.depth is reset
