@@ -76,9 +76,17 @@ ParseEvent (event, parentID)
 
 	if (IsModifierKey(keysym)) return;  /* Don't send modifiers as events */
 
-	keymod = (LockMask | ControlMask | ShiftMask | Mod1Mask)
+	keymod = (LockMask | ControlMask | ShiftMask)
 				& KeyPressedEvent->state;
 
+#ifdef macosx
+	if (KeyPressedEvent->state & (Mod1Mask | Mod2Mask | Mod3Mask
+				| Mod4Mask | Mod5Mask))
+	    keymod |= Mod1Mask;
+#else
+	keymod |= (Mod1Mask & KeyPressedEvent->state);
+#endif
+
 	if (nbytes == 0)  	/* No ASCII equivalent to string */
 	{
 	    keywstate = (keymod << 16) | (keysym & 0xffff);
