@@ -17,7 +17,7 @@
  * pointers in order to achieve graphics display independence.
  */
 
-/* rcsid "$Header: /usr/cvsroot/magic-8.0/graphics/graphics.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $" */
+/* rcsid "$Header: /usr/cvsroot/magic-8.0/graphics/graphics.h,v 1.2 2008/12/11 04:20:06 tim Exp $" */
 
 #ifndef _GRAPHICS_H
 #define	_GRAPHICS_H
@@ -77,10 +77,12 @@ extern bool GrSetDisplay();
 extern bool GrIsDisplay();
 extern void GrLabelSize();
 extern void GrSetStuff();
-extern void GrFastBox();
+extern void GrDrawFastBox();
 extern void GrGuessDisplayType();
 extern int  GrGetStyleFromName();
 
+#define GrFastBox(x)	GrDrawFastBox(x, 0)
+
 /* external color map routines */
 extern bool GrReadCMap(), GrSaveCMap();
 extern bool GrGetColor(), GrPutColor();
