@@ -4,7 +4,7 @@
  * This file defines things that are used by internal LEF routines in
  * various files.
  *
- * rcsid $Header: /usr/cvsroot/magic/lef/lefInt.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic-8.0/lef/lefInt.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $
  */
 
 #ifndef _LEFINT_H
@@ -65,6 +65,7 @@ typedef struct {
     CellDef	*cell;		/* Cell for fixed via def, or NULL	*/
     linkedRect	*lr;		/* Extra information for vias with	*/
 				/* more complicated geometry.		*/
+    TileType	obsType;	/* Secondary obstruction type		*/
 } lefVia;
 
 /* Defined types for "lefClass" in the lefLayer structure */
@@ -73,6 +74,7 @@ typedef struct {
 #define CLASS_VIA	1	/* via or cut layer */
 #define CLASS_MASTER	2	/* masterslice layer */
 #define CLASS_OVERLAP	3	/* overlap layer */
+#define CLASS_IGNORE	4	/* inactive layer */
 
 /* Structure defining a route or via layer and matching it to a magic	*/
 /* layer type.  This structure is saved in the LefInfo hash table.	*/
@@ -118,6 +120,8 @@ char *LefNextToken();
 char *LefLower();
 linkedRect *LefReadGeometry();
 void LefEstimate();
+lefLayer *LefRedefined();
+void LefAddViaGeometry();
 Rect *LefReadRect();
 TileType LefReadLayer();
 
