@@ -23,7 +23,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/mzrouter/mzMain.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/mzrouter/mzMain.c,v 1.2 2008/06/01 18:37:44 tim Exp $";
 #endif  /* not lint */
 
 /*--- includes --- */
@@ -113,9 +113,8 @@ int mzVerbosity;
 /* if positive, upper bound on number of blooms */
 int mzBloomLimit;
 
-/* maskdata tiles, and unexpanded subcells, marked because they are part of 
+/* maskdata unexpanded subcells, marked because they are part of 
  * dest. nodes. */
-List *mzMarkedTilesList;
 List *mzMarkedCellsList;
 
 /* start terminals */
@@ -1275,19 +1274,6 @@ MZClean()
 	{
 	    List *l;
 
-	    /* Reset Marked tiles client fields to CLIENTDEFAULT */
-	    for(l=mzMarkedTilesList; l!=NULL; l=LIST_TAIL(l))
-	    {
-		Tile *tile = (Tile *) LIST_FIRST(l);
-		
-		/* Restore tile client field to its "unmarked" value */
-		tile->ti_client = (ClientData) CLIENTDEFAULT;
-	    }
-
-	    /* Dealloc list of marked tiles */
-	    ListDealloc(mzMarkedTilesList);
-	    mzMarkedTilesList = NULL;
-
 	    /* Reset Marked subcell client fields to CLIENTDEFAULT */
 	    for(l=mzMarkedCellsList; l!=NULL; l=LIST_TAIL(l))
 	    {
