@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowRules3.c,v 1.2 2001/01/12 22:13:12 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/plow/PlowRules3.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -62,7 +62,7 @@ struct inarg
  *
  * Avoid introducing slivers because the plow is too small.
  * This rule only applies if the plow height is less than the
- * maximum design-rule distance TechHalo.
+ * maximum design-rule distance DRCTechHalo.
  *
  * Results:
  *	None.
@@ -82,7 +82,7 @@ prInSliver(edge)
     Plane *plane;
 
     if ((edge->e_flags & E_ISINITIAL) == 0
-	    || edge->e_ytop - edge->e_ybot >= TechHalo)
+	    || edge->e_ytop - edge->e_ybot >= DRCTechHalo)
 	return;
 
     /* Look down from the top of the edge */
