@@ -1,6 +1,6 @@
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/resis/ResMakeRes.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/resis/ResMakeRes.c,v 1.2 2009/01/30 03:11:15 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -794,6 +794,7 @@ ResDoContacts(contact, nodes, resList)
     cElement	 *ccell;
     int		 tilenum, squaresx, squaresy, viawidth;
     int 	 minside, spacing, border;
+    float	 squaresf;
     resResistor	 *resistor;
     resElement	 *element;
     static int	 too_small = 1;
@@ -841,14 +842,16 @@ ResDoContacts(contact, nodes, resList)
 	else
 	{
 	    viawidth += spacing;
-	    squaresx = (contact->cp_width - minside) / viawidth;
-	    squaresx *= ExtCurStyle->exts_unitsPerLambda;
-	    squaresx /= viawidth;
+	    squaresf = (float)(contact->cp_width - minside) / (float)viawidth;
+	    squaresf *= ExtCurStyle->exts_unitsPerLambda;
+	    squaresf /= (float)viawidth;
+	    squaresx = (int)squaresf;
 	    squaresx++;
 
-	    squaresy = (contact->cp_height - minside) / viawidth;
-	    squaresy *= ExtCurStyle->exts_unitsPerLambda;
-	    squaresy /= viawidth;
+	    squaresf = (float)(contact->cp_height - minside) / (float)viawidth;
+	    squaresf *= ExtCurStyle->exts_unitsPerLambda;
+	    squaresf /= (float)viawidth;
+	    squaresy = (int)squaresf;
 	    squaresy++;
 	}
         for (tilenum=0; tilenum < contact->cp_currentcontact; tilenum++)
