@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selCreate.c,v 1.7 2008/12/12 01:29:10 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selCreate.c,v 1.8 2010/05/11 19:28:54 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -1129,6 +1129,7 @@ SelectAndCopy2(newSourceDef)
 	(void) DBSrPaintArea((Tile *) NULL, Select2Def->cd_planes[plane],
 		&TiPlaneRect, &DBAllButSpaceAndDRCBits, selACPaintFunc,
 		(ClientData) plane);
+	DBMergeNMTiles(Select2Def->cd_planes[plane], &TiPlaneRect);
     }
 
     (void) DBCellCopyAllLabels(&scx, &DBAllTypeBits, CU_DESCEND_SPECIAL,
@@ -1238,10 +1239,12 @@ selACPaintFunc2(tile, selACarg)
 
 #ifdef NONMANHATTAN
 
-    if (dinfo & TT_DIAGONAL)
+    if ((dinfo & TT_DIAGONAL) || (type & TT_DIAGONAL))
     {
 	/* If the select area is triangular, then we need to	*/
 	/* clip in a more complicated manner.			*/
+	/* Likewise if the edit cell tile is triangular and	*/
+	/* the select area not.					*/
 
 	Point points[5];
 	Rect rrect, orect;
@@ -1268,7 +1271,10 @@ selACPaintFunc2(tile, selACarg)
 	type = (dinfo & TT_SIDE) ? (rtype << 14) : rtype;
 	type |= dinfo;
 
-	GrClipTriangle(editClip, &selArea, TRUE, dinfo, points, &np);
+	if (dinfo & TT_DIAGONAL)
+	    GrClipTriangle(editClip, &selArea, TRUE, dinfo, points, &np);
+	else
+	    GrClipTriangle(&selArea, editClip, TRUE, type, points, &np);
 
 	if (np == 0)
 	    return 0;
