@@ -20,7 +20,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selEnum.c,v 1.10 2008/12/11 04:20:13 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/select/selEnum.c,v 1.12 2010/05/18 14:21:13 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -155,6 +155,7 @@ SelEnumPaint(layers, editOnly, foundNonEdit, func, clientData)
     arg.sea_cdarg = clientData;
     arg.sea_flags = (editOnly) ? SEA_EDIT_ONLY : 0;
     arg.sea_nonEdit = foundNonEdit;
+    arg.sea_rectList = NULL;
     if (foundNonEdit != NULL) *foundNonEdit = FALSE;
 
     /* First, find all the paint in the selection that has the right
@@ -314,7 +315,7 @@ selEnumPFunc2(tile, arg)
     }
 
     /* For chunk selection, the types have to match exactly, so we don't
-     * pick up bits of compatibly material in another cell that were not
+     * pick up bits of compatible material in another cell that were not
      * intended (a chunk can only exist in one cell)
      */
     if (arg->sea_flags & SEA_CHUNK)
@@ -386,13 +387,12 @@ selEnumPFunc2(tile, arg)
 	int np, i, j;
 	Rect area, orect;
 
-	lr->r_type = ttype | (arg->sea_type & (TT_DIAGONAL | TT_SIDE | TT_DIRECTION));
 	if (!IsSplit(tile))
 	{
 	    /* Things get messy here.  Clip against the select triangle	*/
 	    /* and decompose the result into rectangles and triangles.	*/ 
 
-	    GrClipTriangle(&lr->r_r, &arg->sea_rect, TRUE, lr->r_type, points, &np);
+	    GrClipTriangle(&arg->sea_rect, &lr->r_r, TRUE, arg->sea_type, points, &np);
 
 	    if (np < 3)
 	    {
@@ -468,7 +468,10 @@ topbottom:
 			lr->r_r.r_ybot = area.r_ytop;
 		    }
 		    else
+		    {
+			lr->r_type = ttype;
 			goto splitdone;
+		    }
 
 		    lr->r_type = ttype;
 		    lr->r_next = arg->sea_rectList;
@@ -477,8 +480,26 @@ topbottom:
 		    lr->r_r = area;
 		    lr->r_type = arg->sea_type;
 		}
+		else
+		{
+		    lr->r_r = area;
+		    lr->r_type = arg->sea_type;
+		}
 	    }
 	}
+	else
+	{
+	    /* NOTE:  Need general-purpose triangle-triangle	*/
+	    /* intersection routine here!  However, for most	*/
+	    /* purposes, it suffices to copy the tile if the	*/
+	    /* triangles are similar and to compute the		*/
+	    /* rectangular union are if opposite.		*/
+	    if ((arg->sea_type & TT_SIDE) == (TiGetTypeExact(tile) & TT_SIDE))
+		lr->r_type = ttype | (arg->sea_type &
+			(TT_DIAGONAL | TT_SIDE | TT_DIRECTION));
+	    else
+		lr->r_type = ttype;
+	}
     }
     else
 	lr->r_type = ttype;
