@@ -224,18 +224,25 @@ SimConnectFunc(tile, cx)
     if (DBIsContact(loctype))
     {
 	TileTypeBitMask *rMask = DBResidueMask(loctype);
+	TileTypeBitMask *cMask;
 
 	TTMaskSetOnlyType(&notConnectMask, loctype);
 
 	/* Differenct contact types may share residues (6/18/04) */     
 	for (ctype = TT_TECHDEPBASE; ctype < DBNumUserLayers; ctype++)
-	    if (TTMaskIntersect(rMask, DBResidueMask(ctype)))
+	{
+	    cMask = DBResidueMask(ctype);
+	    if (TTMaskIntersect(rMask, cMask))
 		TTMaskSetType(&notConnectMask, ctype);
+	}
 
 	/* The mask of contact types must include all stacked contacts */
 	for (ctype = DBNumUserLayers; ctype < DBNumTypes; ctype++)   
-	    if TTMaskHasType(DBResidueMask(ctype), loctype)
+	{
+	    cMask = DBResidueMask(ctype);
+	    if TTMaskHasType(cMask, loctype)
 		TTMaskSetType(&notConnectMask, ctype);
+	}
 
 	TTMaskCom(&notConnectMask);
     }
@@ -992,7 +999,7 @@ SimPutLabel(cellDef, rect, align, text, type)
     }
     cellDef->cd_lastLabel = lab;
 
-    DBUndoPutLabel(cellDef, rect, align, text, type, 0);
+    DBUndoPutLabel(cellDef, lab);
     return align;
 }
 
