@@ -580,6 +580,10 @@ proc magic::maketechmanager { mgrpath } {
 
    bind ${mgrpath}.lambda1.lval0 <Return> magic::techparseunits
    bind ${mgrpath}.lambda1.lval1 <Return> magic::techparseunits
+
+   # Withdraw the window and unmark when the "close" button is pressed
+   wm protocol ${mgrpath} WM_DELETE_WINDOW "set Opts(techmgr) 0; \
+		wm withdraw ${mgrpath}"
 }
 
 # Create or redisplay the technology manager
