@@ -17,7 +17,7 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid "$Header: /usr/cvsroot/magic-8.0/tiles/tile.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $"
+ * rcsid "$Header: /usr/cvsroot/magic-8.0/tiles/tile.h,v 1.2 2009/09/10 20:32:54 tim Exp $"
  */
 
 #ifndef _TILES_H
@@ -176,17 +176,17 @@ typedef struct
  * ever needed by modules other than the tile module.
  */
 
-extern Plane *TiNewPlane();
-extern void TiFreePlane();
-extern void TiToRect();
-extern Tile *TiSplitX();
-extern Tile *TiSplitY();
-extern Tile *TiSplitX_Left();
-extern Tile *TiSplitY_Bottom();
-extern void  TiJoinX();
-extern void  TiJoinY();
+extern Plane *TiNewPlane(Tile *);
+extern void TiFreePlane(Plane *);
+extern void TiToRect(Tile *, Rect *);
+extern Tile *TiSplitX(Tile *, int);
+extern Tile *TiSplitY(Tile *, int);
+extern Tile *TiSplitX_Left(Tile *, int);
+extern Tile *TiSplitY_Bottom(Tile *, int);
+extern void  TiJoinX(Tile *, Tile *, Plane *);
+extern void  TiJoinY(Tile *, Tile *, Plane *);
 extern int   TiSrArea();
-extern Tile *TiSrPoint();
+extern Tile *TiSrPoint(Tile *, Plane *, Point *);
 
 #define	TiBottom(tp)		(BOTTOM(tp))
 #define	TiLeft(tp)		(LEFT(tp))
@@ -254,8 +254,8 @@ extern Tile *TiSrPoint();
 #define	TiGetClient(tp)		((tp)->ti_client)
 #define	TiSetClient(tp,b)	((tp)->ti_client = (ClientData)(pointertype) (b))
 
-Tile *TiAlloc();
-void TiFree();
+Tile *TiAlloc(void);
+void TiFree(Tile *);
 
 #define EnclosePoint(tile,point)	((LEFT(tile)   <= (point)->p_x ) && \
 					 ((point)->p_x   <  RIGHT(tile)) && \
