@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/utils/getrect.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/utils/getrect.c,v 1.2 2010/03/08 13:33:34 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -97,6 +97,7 @@ GetRect(fin, skip, rect, scalen, scaled)
     int dir = 0x1;
 #endif
 
+#if !defined(__DragonFly__)
     if (FILE_CNT(fin) < RECTBUFTHRESHOLD) goto slow;
     /*
      * Fast version of GetRect -- read directly from buffer.
@@ -178,6 +179,9 @@ fastbad:
 
     /* Slow version of GetRect -- read via getc */
 slow:
+
+#endif /* __DragonFly__ */
+
     while (skip-- > 0)
 	(void) getc(fin);
 
