@@ -16,7 +16,7 @@
  * Magic utility routines.
  */
 
-/* rcsid "$Header: /usr/cvsroot/magic-8.0/utils/utils.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $" */
+/* rcsid "$Header: /usr/cvsroot/magic-8.0/utils/utils.h,v 1.2 2009/09/10 20:32:55 tim Exp $" */
 
 #ifndef _UTILS_H
 #define _UTILS_H 1
@@ -37,20 +37,20 @@ typedef struct
  */
 
 extern int Lookup();
-extern int LookupAny();
-extern int LookupFull();
+extern int LookupAny(char, char **);
+extern int LookupFull(char *, char **);
 extern int LookupStruct();
 extern int LookupStructFull();
-extern int PaExpand();
+extern int PaExpand(char **, char **, int);
 extern char *nextName();
-extern FILE *PaOpen();
-extern FILE *PaLockOpen();
-extern char *StrDup();
+extern FILE *PaOpen(char *, char *, char *, char *, char *, char **);
+extern FILE *PaLockOpen(char *, char *, char *, char *, char *, char **, bool *);
+extern char *StrDup(char **, char *);
 extern int Match();
 extern char *ArgStr();
-extern bool StrIsWhite();
-extern bool StrIsInt();
-extern bool StrIsNumeric();
+extern bool StrIsWhite(char *, bool);
+extern bool StrIsInt(char *);
+extern bool StrIsNumeric(char *);
 
 extern int SetNoisyBool(bool *, char *, FILE *);
 
